#!/bin/bash

#---------
#@desc 操作记录写日志
#---------
function log(){
    log_str=$1
    type=$2

    #创建log目录
    if [ ! -d "log" ]; then
        mkdir log
    fi

    if [ uname != "Window" ]; then
        log_path=log/`date +%Y-%m-%d`
    else
        log_path=log\\`date +%Y-%m-%d`
    fi

    log_str_pre="$type `date +"%Y-%m-%d %H:%M:%S"` "
    log_str=$log_str_pre$log_str

    echo $log_str >> $log_path
}

#---------
#@desc 得到一个相对唯一的请求id，20位
#@return rid
#---------
function gen_rid() {
    rid=`date +"%Y%m%d%H%M%S"``printf "%.6d" $(($RANDOM%100000+1))`
    echo $rid
}

#---------
#@desc 推送数据
#@url 推送接口
#@post_data 推送数据 array类型
#---------
function post_json_data() {
    url=$1
    post_data=$2 #数组形式

    #对请求的接口加一个请求id，方便定位问题
    rid=`gen_rid`
    url=$url"&rid="$rid

    data=""
    count=0
    for row in ${post_data[*]}; do
        data=$data"$row""\n"
        count=$(($count+1))
    done
    #临时写文件，避免直接推数据，换行符不能被解析
    echo $data > tmp

    send_size=`echo ${#data}`
    #数据量大于限制值的包不发送
    if [ $send_size -gt 10485760 ]; then
        log_str="\x01rid\x02"$rid"\x01msg\x02请求包大小应小于10M"
        log "$log_str" "ERROR"
        return -1
    fi

    #记录当前请求记录
    send_num=$count  #${#post_data[@]}
    log_str="\x01rid\x02"$rid"\x01send_size\x02"$send_size"\x01send_num\x02"$send_num
    log "$log_str" "NOTICE"

    res=`curl -s -S -H "content-type: application/json" --data-binary @tmp $url`
    res_new=`echo "$res"|tr -d "\r\n\t"|xargs`

    match=`echo $res_new|grep "code:200"`
    if [ "$match"x != ""x ]; then
        #服务正常接收到数据的请求返回 获取id和recv_num
        logid=`echo $res_new|grep -Eo 'id:(.*?)}'|grep -Eo '[0-9]+'`
        recv_num=`echo $res_new|grep -Eo 'recv_num:(.*?),'|grep -Eo '[0-9]+'`

        log_str="\x01rid\x02"$rid"\x01server_logid\x02"$logid"\x01recv_num\x02"$recv_num"\x01msg\x02"$res_new
        log "$log_str" "NOTICE"
    else
        #服务未接收到数据的请求返回
        log_str="\x01rid\x02"$rid"\x01error\x02""$res_new"
        log "$log_str" "ERROR"
    fi
}